#include "client/Client.h"
#include "client/render/Display.h"
#include "client/render/WorldRenderer.h"

int main(int argc, char** argv) {

	blitz::Client client;
	blitz::Display display(1920, 1080, "BlitzKrieg", &client);

	if (!display.Create())
		return EXIT_FAILURE;

	blitz::render::WorldRenderer renderer(&client);

	while (!display.IsCloseRequested()) {
		client.Update();
		display.PollEvents();
		renderer.Render();
		display.Render();
		display.Update();
	}

	display.Destroy();

	return 0;
}
